<?php
/**
 * Deep Light.
 *
 * @since   1.0.4
 * @author  Webnus
 */

// Don't load directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Deep_Light_Admin {

	/**
	 * Instance of this class.
	 *
	 * @since   1.0.4
	 * @access  public
	 * @var     Deep_Light_Admin
	 */
	public static $instance;

	/**
	 * Page title.
	 *
	 * @since   1.0.4	 
	 * @var     page_title
	 */
	public static $page_title = 'Deep';

	/**
	 * Menu title.
	 *
	 * @since   1.0.4	 
	 * @var     menu_title
	 */
	public static $menu_title = 'Deep Theme';

	/**
	 * Plugin Slug.
	 *
	 * @since   1.0.4	 
	 * @var     plugin_slug
	 */
	public static $plugin_slug = 'deep';
	
	/**
	 * Provides access to a single instance of a module using the singleton pattern.
	 *
	 * @since   1.0.4
	 * @return  object
	 */
	public static function get_instance() {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Define the core functionality of the theme.
	 *
	 * Load the dependencies.
	 *
	 * @since   1.0.4
	 */
	public function __construct() {
        
        if ( ! is_admin() ) {
            return;
        }        

		add_action( 'admin_menu', [$this, 'deep_light_admin_menu'] );
		add_action( 'deep_light_rate', [$this, 'deep_light_rate'] );		
		add_action( 'deep_light_community', [$this, 'deep_light_community'] );
		add_action( 'admin_enqueue_scripts', [$this, 'deep_light_admin_assets'] );
		add_action( 'deep_light_admin_header', [$this, 'deep_light_admin_header'] );
		add_action( 'deep_light_more_options', [$this, 'deep_light_more_options'] );
		add_action( 'deep_light_admin_content', [$this, 'deep_light_admin_content'] );
		add_action( 'deep_light_plugin_notice', [$this, 'deep_light_plugin_notice'] );		
		add_action( 'deep_light_knowledge_base', [$this, 'deep_light_knowledge_base'] );
		add_action( 'deep_light_import_template', [$this, 'deep_light_import_template'] );		
		add_action( 'deep_light_customizer_links', [$this, 'deep_light_customizer_links'] );

	}
	
	/**
	 * Deep Light Admin Assets.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_admin_assets() {
		
		wp_enqueue_style( 'deep-light-admin-page', DEEP_LIGHT_THEME_URI . 'inc/assets/css/deep-light-admin-page.css' , array(), DEEPLIGHT );
		
	}
	
	/**
	 * Deep Light Admin Menu.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_admin_menu() {

		$capability = 'manage_options';
		$menu_slug  = self::$plugin_slug;
		$page_title = self::$page_title;
		$menu_title = self::$menu_title;
		$admin_menu_callback = __CLASS__ . '::deep_light_admin_menu_callback';

		add_theme_page( $page_title, $menu_title, $capability, $menu_slug, $admin_menu_callback );
		
	}
	
	/**
	 * Deep Light Admin Menu Callback.
	 *
	 * @since   1.0.4
	 */
	public static function deep_light_admin_menu_callback() {
		
		?>
		<div class="deep-light-admin-page">
			<?php 
				do_action( 'deep_light_admin_header' );
				do_action( 'deep_light_admin_content' );
			?>
		</div>
		<?php

	}

	/**
	 * Deep Light Admin Header.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_admin_header() {

		?>
		<div class="deep-light-admin-header">
			<div class="dp-admin-top-bar">
				<div class="dp-admin-top-title">
					<a href="<?php echo esc_url( 'https://webnus.net/deep-premium-wordpress-theme/' ); ?>" target="_blank">
						<img src="<?php echo DEEP_LIGHT_THEME_URI . 'inc/assets/img/deep-logo.svg' ?>" width="120">
					</a>
				</div>
				<div class="dp-admin-top-links">						
					<a href="<?php echo esc_url( 'https://webnus.net/deep-premium-wordpress-theme/' ) ?>" target="_blank"><?php esc_html_e( 'Intro', 'deep-light' ); ?></a>					
					<a href="<?php echo esc_url( 'https://webnus.net/deep-premium-wordpress-theme/#demos' ) ?>" target="_blank"><?php esc_html_e( 'Demos', 'deep-light' ); ?></a>					
					<a href="<?php echo esc_url( 'https://webnus.net/pricing/' ) ?>" target="_blank"><?php esc_html_e( 'Pro', 'deep-light' ); ?></a>					
					<a href="<?php echo esc_url( 'https://webnus.net/support/' ); ?>" target="_blank"><?php esc_html_e( 'Support', 'deep-light' ); ?></a>
					<a href="<?php echo esc_url( 'https://webnus.net/deep-premium-wordpress-theme-documentation/' ); ?>" target="_blank"><?php esc_html_e( 'Help', 'deep-light' ); ?></a>
				</div>
			</div>
		</div>
		<?php

	}

	/**
	 * Deep Light Admin Content.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_admin_content() {
		
		?>
		<div class="deep-light-admin-content">
			<?php
				do_action( 'deep_light_plugin_notice' );					
			?>
			<div class="deep-light-admin-left">
			<?php 
				do_action( 'deep_light_customizer_links' );
				do_action( 'deep_light_more_options' );
			?>
			</div>
			<div class="deep-light-admin-right">
			<?php 
				do_action( 'deep_light_import_template' );
				do_action( 'deep_light_knowledge_base' );
				do_action( 'deep_light_community' );
				do_action( 'deep_light_rate' );
			?>
			</div>			
		</div>
		<?php

	}

	/**
	 * Deep Light Install plugin Notice.
	 *
	 * @since   1.0.4
	 */
	public static function deep_light_plugin_notice() {
		
		?>
		<div class="deep-light-plugin-notice">
			<?php if( ! defined( 'DEEPCORE' ) ): ?>
				<h2><?php esc_attr_e( 'Enable all Features of the Deep theme', 'deep-light' ); ?></h2>
				<p><?php esc_attr_e( 'In order to take full advantage of the Deep theme and enabling its demo importer, please install the recommended plugins.', 'deep-light' ); ?></p>
				<a href="<?php echo esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ); ?>" target="_blank"><?php esc_attr_e( 'Install Plugin', 'deep-light' ); ?></a>
			<?php else: ?>
				<h2><?php esc_attr_e( 'Go Pro & Full Access to Advanced Features', 'deep-light' ); ?></h2>
				<p><?php esc_attr_e( 'Get full access to more demos and all advanced features of Deep theme by upgrading to Pro version right away.', 'deep-light' ); ?></p>
				<a href="<?php echo esc_url( 'https://webnus.net/pricing/' ); ?>" target="_blank"><?php esc_attr_e( 'Go Pro', 'deep-light' ); ?></a>
			<?php endif; ?>
		</div>
		<?php

	}

	/**
	 * Deep Light Customizer Links.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_customizer_links() {

		if ( is_plugin_active( 'deepcore/deepcore.php' ) ) {
			
			$customizer_url = admin_url( 'customize.php' ) . '?autofocus[panel]=';
			
			$customizer_links = apply_filters(
				'deep_customizer_links',
				array(
					'general' => array(
						'name'     => __( 'General', 'deep-light' ),
						'icon'  => 'dashicons-admin-generic',
						'url' => $customizer_url . 'general_opts',
					),
					'typography'       => array(
						'name'     => __( 'Typography', 'deep-light' ),
						'icon'  => 'dashicons-editor-textcolor',
						'url' => $customizer_url . 'typography_opts',
					),
					'blog'   => array(
						'name'     => __( 'Blog Settings', 'deep-light' ),
						'icon'  => 'dashicons-welcome-write-blog',
						'url' => $customizer_url . 'blog-opts',
					),
					'styling'       => array(
						'name'     => __( 'Styling', 'deep-light' ),
						'icon'  => 'dashicons-layout',
						'url' => $customizer_url . 'styling_opts',
					),
					'header-builder'       => array(
						'name'     => __( 'Header Builder', 'deep-light' ),
						'icon'  => 'dashicons-align-center',
						'url' => admin_url( 'admin.php?page=webnus_header_builder' ),
					),
					'pages'  => array(
						'name'     => __( 'Pages Settings', 'deep-light' ),
						'icon'  => 'dashicons-welcome-write-blog',
						'url' => $customizer_url . 'pages_opts',
					),
					'footer'       => array(
						'name'     => __( 'Footer Settings', 'deep-light' ),
						'icon'  => 'dashicons-admin-generic',
						'url' => $customizer_url . 'start_footer_opts',
					),
					'sidebars'     => array(
						'name'     => __( 'Site Identity', 'deep-light' ),
						'icon'  => 'dashicons-format-image',
						'url' => admin_url( 'customize.php?autofocus[section]=title_tagline' ),
					),
				)
			);

			?>

			<div class="deep-light-customizer-links">
				<h2 class="deep-light-admin-title">
				<i class="dashicons dashicons-admin-customizer"></i>
				<?php esc_html_e( 'Start Customizing', 'deep-light' ); ?>				
				</h2>
				<?php
				if ( ! empty( $customizer_links ) ) :
					?>					
					<ul class="customizer-links">
						<?php
						foreach ( $customizer_links as $link ) {
							echo '<li><a href="' . esc_url( $link['url'] ) . '" target="_blank"><span class="dashicons ' . esc_attr( $link['icon'] ) . '"></span> ' . esc_html( $link['name'] ) . '</a></li>';
						}
						?>
					</ul>					
				<?php endif; ?>			
			</div>

			<?php
		}			

	}

	/**
	 * Deep Light More Options.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_more_options() {

		$more_options = apply_filters(
			'deep_light_pro_options',
			array(																		
				'header-builder' => array(
					'title' => __( 'Header Builder', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/header-builder/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),
				'defined-headers' => array(
					'title' => __( 'Pre-defined Headers', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/import-pre-defined-headers/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),	
				'footer-builder' => array(
					'title' => __( 'Footer Builder', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/footer-builder/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),		
				'portfolio' => array(
					'title' => __( 'Portfolio', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/webnus-portfolio/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),		
				'gallery' => array(
					'title' => __( 'Gallery', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/webnus-gallery/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),		
				'shop' => array(
					'title' => __( 'Shop', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/shop-theme-options/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),		
				'typography' => array(
					'title' => __( 'Typography', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/typography/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),		
				'blog' => array(
					'title' => __( 'Blog Options', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/blog-options/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),		
				'importer' => array(
					'title' => __( 'One Click Demo Importer', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/import-demo/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),		
				'plugins' => array(
					'title' => __( 'Premium Plugins', 'deep-light' ),																				
					'link'  => array(
						'url'     =>   'https://webnus.net/deep-premium-wordpress-theme-documentation/other-premium-plugins/',
						'text'    => __( 'Learn More', 'deep-light' ),						
					),
				),		
			)
		);
		
		?>
		<div class="deep-light-more-options">
			<h2 class="deep-light-admin-title">
			<i class="dashicons dashicons-star-filled"></i>
			<?php esc_html_e( 'Deep Features', 'deep-light' ); ?>
			</h2>
			<?php
			if ( ! empty( $more_options ) ) :
				?>					
				<ul class="pro-more-options">
					<?php
						foreach ( $more_options as $option ) {
							$title = $option['title'];
							$url   = $option['link']['url'];
							$text  = $option['link']['text'];
							
							echo '<li>';
								echo '<a href="' . esc_url( $url ) . '" target="_blank"> ' . esc_html( $title ) . ' <span> ' . esc_html( $text ) . ' <i class="dashicons dashicons-arrow-right-alt2"></i> </span> </a>';								
							echo '</li>';
						}
					?>
				</ul>					
			<?php endif; ?>			
		</div>
		<?php

	}

	/**
	 * Deep Light Import Starter Template.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_import_template() {
		
		?>
		<div class="deep-light-import-template deep-light-r-admin">
			<h2><i class="dashicons dashicons-database-import"></i> <?php esc_html_e( 'Demo Importer', 'deep-light' ); ?></h2>
			<img src="<?php echo esc_url( DEEP_LIGHT_THEME_URI . 'inc/assets/img/deep-importer-sc05.png' ); ?>" width="245">
			<p>
			<?php esc_html_e( 'In order to import the demo, you need to install the Deep Core plugin.', 'deep-light' ); ?>
			</p>
			<p>
			<?php esc_html_e( 'Click', 'deep-light' ); ?> <a href="<?php echo esc_url( 'https://webnus.net/deep-premium-wordpress-theme-documentation/import-demo/' )?>" target="_blank"><?php esc_html_e( 'here', 'deep-light' ); ?></a><?php esc_html_e( ' to see the documentation.', 'deep-light' ); ?>			
			</p>
		</div>
		<?php

	}

	/**
	 * Deep Light Knowledge Base.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_knowledge_base() {
		
		?>
		<div class="deep-light-knowledge-base deep-light-r-admin">
			<h2><i class="dashicons dashicons-book"></i> <?php esc_html_e( 'Knowledge Base', 'deep-light' ); ?></h2>
			<p><?php esc_html_e( 'To find out more details of the features and sections please follow the documentation.', 'deep-light' ); ?></p>
			<p><a href="<?php echo esc_url( 'https://webnus.net/deep-premium-wordpress-theme-documentation/' ); ?>" target="_blank"><?php esc_html_e( 'Documentation', 'deep-light' ); ?></a></p>
		</div>
		<?php

	}

	/**
	 * Deep Light Community.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_community() {
		
		?>
		<div class="deep-light-community deep-light-r-admin">
			<h2><i class="dashicons dashicons-reddit"></i> <?php esc_html_e( 'Deep Theme Community', 'deep-light' ); ?></h2>
			<p><?php esc_html_e( 'Join the Deep Theme subreddit to get help and ask your technical questions.', 'deep-light' ); ?></p>
			<p><a href="<?php echo esc_url( '#' ); ?>" target="_blank"><?php esc_html_e( 'Join The Deep Theme Subreddit ', 'deep-light' ); ?></a></p>
		</div>
		<?php

	}

	/**
	 * Deep Light Rate.
	 *
	 * @since   1.0.4
	 */
	public function deep_light_rate() {
		
		?>
		<div class="deep-light-rate deep-light-r-admin">
			<h2><i class="dashicons dashicons-star-filled"></i> <?php esc_html_e( 'Rate us', 'deep-light' ); ?></h2>
			<p><?php esc_html_e( 'If you interested in the Deep Theme please rate us on WordPress.', 'deep-light' ); ?></p>
			<p><a href="<?php echo esc_url( 'https://wordpress.org/support/theme/deep-light/reviews/' ); ?>" target="_blank"><?php esc_html_e( 'Rate Us', 'deep-light' ); ?></a></p>
		</div>
		<?php

	}

}
// Run
Deep_Light_Admin::get_instance();